==> haskell-js-chart-2.9.4.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-chart.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-chart
version:              2.9.4.1
visibility:           public
id:                   js-chart-2.9.4.1-DuzjunIu90bBElouISVjWv
key:                  js-chart-2.9.4.1-DuzjunIu90bBElouISVjWv
license:              MIT
copyright:
    Jonas Carpay 2020, Neil Mitchell 2014-2020, Chart.js contributors 2020

maintainer:           Jonas Carpay <jonascarpay@gmail.com>
author:               Jonas Carpay <jonascarpay@gmail.com>
homepage:             https://github.com/jonascarpay/js-chart#readme
synopsis:             Obtain minified chart.js code
description:
    This package bundles the minified <http://www.chartjs.org/ chart.js> code into a Haskell package, so it can be depended upon by Cabal packages.
    The first three components of the version number match the upstream chart.js version.
    The package is designed to meet the redistribution requirements of downstream users (e.g. Debian).
    This package is a fork of <https://hackage.haskell.org/package/js-flot js-flot> using chart.js instead of flot.

category:             Javascript
abi:                  5fb5b1e17082ab882228a1f7cff3a96c
exposed:              True
exposed-modules:      Language.Javascript.Chart
hidden-modules:       Paths_js_chart
import-dirs:          /usr/lib/ghc-9.0.1/site-local/js-chart-2.9.4.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/js-chart-2.9.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/js-chart-2.9.4.1
hs-libraries:         HSjs-chart-2.9.4.1-DuzjunIu90bBElouISVjWv
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-js-chart/html/js-chart.haddock
haddock-html:         /usr/share/doc/haskell-js-chart/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-chart-2.9.4.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-chart.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-chart
version:              2.9.4.1
visibility:           public
id:                   js-chart-2.9.4.1-Flj5BKolsep7sdg9Mb6p76
key:                  js-chart-2.9.4.1-Flj5BKolsep7sdg9Mb6p76
license:              MIT
copyright:
    Jonas Carpay 2020, Neil Mitchell 2014-2020, Chart.js contributors 2020

maintainer:           Jonas Carpay <jonascarpay@gmail.com>
author:               Jonas Carpay <jonascarpay@gmail.com>
homepage:             https://github.com/jonascarpay/js-chart#readme
synopsis:             Obtain minified chart.js code
description:
    This package bundles the minified <http://www.chartjs.org/ chart.js> code into a Haskell package, so it can be depended upon by Cabal packages.
    The first three components of the version number match the upstream chart.js version.
    The package is designed to meet the redistribution requirements of downstream users (e.g. Debian).
    This package is a fork of <https://hackage.haskell.org/package/js-flot js-flot> using chart.js instead of flot.

category:             Javascript
abi:                  bd531d5b74467a15652288de1d884f6c
exposed:              True
exposed-modules:      Language.Javascript.Chart
hidden-modules:       Paths_js_chart
import-dirs:          /usr/lib/ghc-9.0.2/site-local/js-chart-2.9.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/js-chart-2.9.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/js-chart-2.9.4.1
hs-libraries:         HSjs-chart-2.9.4.1-Flj5BKolsep7sdg9Mb6p76
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-js-chart/html/js-chart.haddock
haddock-html:         /usr/share/doc/haskell-js-chart/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
